translate.convert.po2csv.po2csv

Package translate :: Package convert :: Module po2csv :: Class po2csv |
[hide private]
[frames] | no frames]

# Class po2csv

source code

Instance Methods | [hide private]
convertcomments(self, inputunit) | source code
convertunit(self, inputunit) | source code
convertplurals(self, inputunit) Convert PO plural units | source code
convertstore(self, inputstore, columnorder=None) | source code

Method Details | [hide private]

### convertplurals(self, inputunit) | source code
Convert PO plural units We only convert the first plural form. So languages with multiple plurals are not handled. For single plural languages we simply skip this plural extraction.